==> pmml-model-1.0.0-sources.jar: org/dmg/pmml/VectorDictionary.java <==

package org.dmg.pmml;

import java.math.BigInteger;
import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.jvnet.jaxb2_commons.lang.Equals;
import org.jvnet.jaxb2_commons.lang.EqualsStrategy;
import org.jvnet.jaxb2_commons.lang.HashCode;
import org.jvnet.jaxb2_commons.lang.HashCodeStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBEqualsStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBHashCodeStrategy;
import org.jvnet.jaxb2_commons.locator.ObjectLocator;
import org.jvnet.jaxb2_commons.locator.util.LocatorUtils;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_1}Extension" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_1}VectorFields"/>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_1}VectorInstance" maxOccurs="unbounded" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="numberOfVectors" type="{http://www.dmg.org/PMML-4_1}INT-NUMBER" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "extensions",
    "vectorFields",
    "vectorInstances"
})
@XmlRootElement(name = "VectorDictionary")
public class VectorDictionary
    extends PMMLObject
    implements Equals, HashCode
{

    @XmlElement(name = "Extension")
    protected List<Extension> extensions;
    @XmlElement(name = "VectorFields", required = true)
    protected VectorFields vectorFields;
    @XmlElement(name = "VectorInstance")
    protected List<VectorInstance> vectorInstances;
    @XmlAttribute(name = "numberOfVectors")
    protected BigInteger numberOfVectors;

    @Deprecated
    public VectorDictionary() {
        super();
    }

    public VectorDictionary(final VectorFields vectorFields) {
        super();
        this.vectorFields = vectorFields;
    }

    /**
     * Gets the value of the extensions property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the extensions property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getExtensions().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Extension }
     * 
     * 
     */
    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    /**
     * Gets the value of the vectorFields property.
     * 
     * @return
     *     possible object is
     *     {@link VectorFields }
     *     
     */
    public VectorFields getVectorFields() {
        return vectorFields;
    }

    /**
     * Sets the value of the vectorFields property.
     * 
     * @param value
     *     allowed object is
     *     {@link VectorFields }
     *     
     */
    public void setVectorFields(VectorFields value) {
        this.vectorFields = value;
    }

    /**
     * Gets the value of the vectorInstances property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the vectorInstances property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getVectorInstances().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link VectorInstance }
     * 
     * 
     */
    public List<VectorInstance> getVectorInstances() {
        if (vectorInstances == null) {
            vectorInstances = new ArrayList<VectorInstance>();
        }
        return this.vectorInstances;
    }

    /**
     * Gets the value of the numberOfVectors property.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getNumberOfVectors() {
        return numberOfVectors;
    }

    /**
     * Sets the value of the numberOfVectors property.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setNumberOfVectors(BigInteger value) {
        this.numberOfVectors = value;
    }

    public boolean equals(ObjectLocator thisLocator, ObjectLocator thatLocator, Object object, EqualsStrategy strategy) {
        if (!(object instanceof VectorDictionary)) {
            return false;
        }
        if (this == object) {
            return true;
        }
        if (!super.equals(thisLocator, thatLocator, object, strategy)) {
            return false;
        }
        final VectorDictionary that = ((VectorDictionary) object);
        {
            List<Extension> lhsExtensions;
            lhsExtensions = (((this.extensions!= null)&&(!this.extensions.isEmpty()))?this.getExtensions():null);
            List<Extension> rhsExtensions;
            rhsExtensions = (((that.extensions!= null)&&(!that.extensions.isEmpty()))?that.getExtensions():null);
            if (!strategy.equals(LocatorUtils.property(thisLocator, "extensions", lhsExtensions), LocatorUtils.property(thatLocator, "extensions", rhsExtensions), lhsExtensions, rhsExtensions)) {
                return false;
            }
        }
        {
            VectorFields lhsVectorFields;
            lhsVectorFields = this.getVectorFields();
            VectorFields rhsVectorFields;
            rhsVectorFields = that.getVectorFields();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "vectorFields", lhsVectorFields), LocatorUtils.property(thatLocator, "vectorFields", rhsVectorFields), lhsVectorFields, rhsVectorFields)) {
                return false;
            }
        }
        {
            List<VectorInstance> lhsVectorInstances;
            lhsVectorInstances = (((this.vectorInstances!= null)&&(!this.vectorInstances.isEmpty()))?this.getVectorInstances():null);
            List<VectorInstance> rhsVectorInstances;
            rhsVectorInstances = (((that.vectorInstances!= null)&&(!that.vectorInstances.isEmpty()))?that.getVectorInstances():null);
            if (!strategy.equals(LocatorUtils.property(thisLocator, "vectorInstances", lhsVectorInstances), LocatorUtils.property(thatLocator, "vectorInstances", rhsVectorInstances), lhsVectorInstances, rhsVectorInstances)) {
                return false;
            }
        }
        {
            BigInteger lhsNumberOfVectors;
            lhsNumberOfVectors = this.getNumberOfVectors();
            BigInteger rhsNumberOfVectors;
            rhsNumberOfVectors = that.getNumberOfVectors();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "numberOfVectors", lhsNumberOfVectors), LocatorUtils.property(thatLocator, "numberOfVectors", rhsNumberOfVectors), lhsNumberOfVectors, rhsNumberOfVectors)) {
                return false;
            }
        }
        return true;
    }

    public boolean equals(Object object) {
        final EqualsStrategy strategy = JAXBEqualsStrategy.INSTANCE;
        return equals(null, null, object, strategy);
    }

    public int hashCode(ObjectLocator locator, HashCodeStrategy strategy) {
        int currentHashCode = super.hashCode(locator, strategy);
        {
            List<Extension> theExtensions;
            theExtensions = (((this.extensions!= null)&&(!this.extensions.isEmpty()))?this.getExtensions():null);
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "extensions", theExtensions), currentHashCode, theExtensions);
        }
        {
            VectorFields theVectorFields;
            theVectorFields = this.getVectorFields();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "vectorFields", theVectorFields), currentHashCode, theVectorFields);
        }
        {
            List<VectorInstance> theVectorInstances;
            theVectorInstances = (((this.vectorInstances!= null)&&(!this.vectorInstances.isEmpty()))?this.getVectorInstances():null);
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "vectorInstances", theVectorInstances), currentHashCode, theVectorInstances);
        }
        {
            BigInteger theNumberOfVectors;
            theNumberOfVectors = this.getNumberOfVectors();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "numberOfVectors", theNumberOfVectors), currentHashCode, theNumberOfVectors);
        }
        return currentHashCode;
    }

    public int hashCode() {
        final HashCodeStrategy strategy = JAXBHashCodeStrategy.INSTANCE;
        return this.hashCode(null, strategy);
    }

}

==> pmml-model-1.0.1-sources.jar: org/dmg/pmml/VectorDictionary.java <==

package org.dmg.pmml;

import java.math.BigInteger;
import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.jvnet.jaxb2_commons.lang.Equals;
import org.jvnet.jaxb2_commons.lang.EqualsStrategy;
import org.jvnet.jaxb2_commons.lang.HashCode;
import org.jvnet.jaxb2_commons.lang.HashCodeStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBEqualsStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBHashCodeStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBToStringStrategy;
import org.jvnet.jaxb2_commons.lang.ToString;
import org.jvnet.jaxb2_commons.lang.ToStringStrategy;
import org.jvnet.jaxb2_commons.locator.ObjectLocator;
import org.jvnet.jaxb2_commons.locator.util.LocatorUtils;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_1}Extension" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_1}VectorFields"/>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_1}VectorInstance" maxOccurs="unbounded" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="numberOfVectors" type="{http://www.dmg.org/PMML-4_1}INT-NUMBER" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "extensions",
    "vectorFields",
    "vectorInstances"
})
@XmlRootElement(name = "VectorDictionary")
public class VectorDictionary
    extends PMMLObject
    implements Equals, HashCode, ToString
{

    @XmlElement(name = "Extension")
    protected List<Extension> extensions;
    @XmlElement(name = "VectorFields", required = true)
    protected VectorFields vectorFields;
    @XmlElement(name = "VectorInstance")
    protected List<VectorInstance> vectorInstances;
    @XmlAttribute(name = "numberOfVectors")
    protected BigInteger numberOfVectors;

    @Deprecated
    public VectorDictionary() {
        super();
    }

    public VectorDictionary(final VectorFields vectorFields) {
        super();
        this.vectorFields = vectorFields;
    }

    /**
     * Gets the value of the extensions property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the extensions property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getExtensions().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Extension }
     * 
     * 
     */
    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    /**
     * Gets the value of the vectorFields property.
     * 
     * @return
     *     possible object is
     *     {@link VectorFields }
     *     
     */
    public VectorFields getVectorFields() {
        return vectorFields;
    }

    /**
     * Sets the value of the vectorFields property.
     * 
     * @param value
     *     allowed object is
     *     {@link VectorFields }
     *     
     */
    public void setVectorFields(VectorFields value) {
        this.vectorFields = value;
    }

    /**
     * Gets the value of the vectorInstances property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the vectorInstances property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getVectorInstances().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link VectorInstance }
     * 
     * 
     */
    public List<VectorInstance> getVectorInstances() {
        if (vectorInstances == null) {
            vectorInstances = new ArrayList<VectorInstance>();
        }
        return this.vectorInstances;
    }

    /**
     * Gets the value of the numberOfVectors property.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getNumberOfVectors() {
        return numberOfVectors;
    }

    /**
     * Sets the value of the numberOfVectors property.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setNumberOfVectors(BigInteger value) {
        this.numberOfVectors = value;
    }

    public boolean equals(ObjectLocator thisLocator, ObjectLocator thatLocator, Object object, EqualsStrategy strategy) {
        if (!(object instanceof VectorDictionary)) {
            return false;
        }
        if (this == object) {
            return true;
        }
        if (!super.equals(thisLocator, thatLocator, object, strategy)) {
            return false;
        }
        final VectorDictionary that = ((VectorDictionary) object);
        {
            List<Extension> lhsExtensions;
            lhsExtensions = (((this.extensions!= null)&&(!this.extensions.isEmpty()))?this.getExtensions():null);
            List<Extension> rhsExtensions;
            rhsExtensions = (((that.extensions!= null)&&(!that.extensions.isEmpty()))?that.getExtensions():null);
            if (!strategy.equals(LocatorUtils.property(thisLocator, "extensions", lhsExtensions), LocatorUtils.property(thatLocator, "extensions", rhsExtensions), lhsExtensions, rhsExtensions)) {
                return false;
            }
        }
        {
            VectorFields lhsVectorFields;
            lhsVectorFields = this.getVectorFields();
            VectorFields rhsVectorFields;
            rhsVectorFields = that.getVectorFields();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "vectorFields", lhsVectorFields), LocatorUtils.property(thatLocator, "vectorFields", rhsVectorFields), lhsVectorFields, rhsVectorFields)) {
                return false;
            }
        }
        {
            List<VectorInstance> lhsVectorInstances;
            lhsVectorInstances = (((this.vectorInstances!= null)&&(!this.vectorInstances.isEmpty()))?this.getVectorInstances():null);
            List<VectorInstance> rhsVectorInstances;
            rhsVectorInstances = (((that.vectorInstances!= null)&&(!that.vectorInstances.isEmpty()))?that.getVectorInstances():null);
            if (!strategy.equals(LocatorUtils.property(thisLocator, "vectorInstances", lhsVectorInstances), LocatorUtils.property(thatLocator, "vectorInstances", rhsVectorInstances), lhsVectorInstances, rhsVectorInstances)) {
                return false;
            }
        }
        {
            BigInteger lhsNumberOfVectors;
            lhsNumberOfVectors = this.getNumberOfVectors();
            BigInteger rhsNumberOfVectors;
            rhsNumberOfVectors = that.getNumberOfVectors();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "numberOfVectors", lhsNumberOfVectors), LocatorUtils.property(thatLocator, "numberOfVectors", rhsNumberOfVectors), lhsNumberOfVectors, rhsNumberOfVectors)) {
                return false;
            }
        }
        return true;
    }

    public boolean equals(Object object) {
        final EqualsStrategy strategy = JAXBEqualsStrategy.INSTANCE;
        return equals(null, null, object, strategy);
    }

    public int hashCode(ObjectLocator locator, HashCodeStrategy strategy) {
        int currentHashCode = super.hashCode(locator, strategy);
        {
            List<Extension> theExtensions;
            theExtensions = (((this.extensions!= null)&&(!this.extensions.isEmpty()))?this.getExtensions():null);
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "extensions", theExtensions), currentHashCode, theExtensions);
        }
        {
            VectorFields theVectorFields;
            theVectorFields = this.getVectorFields();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "vectorFields", theVectorFields), currentHashCode, theVectorFields);
        }
        {
            List<VectorInstance> theVectorInstances;
            theVectorInstances = (((this.vectorInstances!= null)&&(!this.vectorInstances.isEmpty()))?this.getVectorInstances():null);
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "vectorInstances", theVectorInstances), currentHashCode, theVectorInstances);
        }
        {
            BigInteger theNumberOfVectors;
            theNumberOfVectors = this.getNumberOfVectors();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "numberOfVectors", theNumberOfVectors), currentHashCode, theNumberOfVectors);
        }
        return currentHashCode;
    }

    public int hashCode() {
        final HashCodeStrategy strategy = JAXBHashCodeStrategy.INSTANCE;
        return this.hashCode(null, strategy);
    }

    public String toString() {
        final ToStringStrategy strategy = JAXBToStringStrategy.INSTANCE;
        final StringBuilder buffer = new StringBuilder();
        append(null, buffer, strategy);
        return buffer.toString();
    }

    public StringBuilder append(ObjectLocator locator, StringBuilder buffer, ToStringStrategy strategy) {
        strategy.appendStart(locator, this, buffer);
        appendFields(locator, buffer, strategy);
        strategy.appendEnd(locator, this, buffer);
        return buffer;
    }

    public StringBuilder appendFields(ObjectLocator locator, StringBuilder buffer, ToStringStrategy strategy) {
        super.appendFields(locator, buffer, strategy);
        {
            List<Extension> theExtensions;
            theExtensions = (((this.extensions!= null)&&(!this.extensions.isEmpty()))?this.getExtensions():null);
            strategy.appendField(locator, this, "extensions", buffer, theExtensions);
        }
        {
            VectorFields theVectorFields;
            theVectorFields = this.getVectorFields();
            strategy.appendField(locator, this, "vectorFields", buffer, theVectorFields);
        }
        {
            List<VectorInstance> theVectorInstances;
            theVectorInstances = (((this.vectorInstances!= null)&&(!this.vectorInstances.isEmpty()))?this.getVectorInstances():null);
            strategy.appendField(locator, this, "vectorInstances", buffer, theVectorInstances);
        }
        {
            BigInteger theNumberOfVectors;
            theNumberOfVectors = this.getNumberOfVectors();
            strategy.appendField(locator, this, "numberOfVectors", buffer, theNumberOfVectors);
        }
        return buffer;
    }

}
